Rule: In General
================

.. toctree::

   rule
   rule_iterated_elimination
   rule_score
   rule_score_num
   rule_score_num_average
   rule_score_num_row_sum
   rule_score_positional
   rule_sequential_elimination
   rule_sequential_tie_break
